aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/core/common_runtime/memory_types.cc
diff options
context:
space:
mode:
Diffstat (limited to 'tensorflow/core/common_runtime/memory_types.cc')
-rw-r--r--tensorflow/core/common_runtime/memory_types.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/tensorflow/core/common_runtime/memory_types.cc b/tensorflow/core/common_runtime/memory_types.cc
index db053dd2fa..21ed73df77 100644
--- a/tensorflow/core/common_runtime/memory_types.cc
+++ b/tensorflow/core/common_runtime/memory_types.cc
@@ -47,12 +47,12 @@ struct EndpointEq {
static Status ProcessMemoryTypes(
const DeviceType& device_type, const Graph* g,
const std::function<Status(const Edge*, MemoryType, MemoryType)>& fn) {
- if (device_type != DEVICE_GPU) {
- // On non-GPU devices, HOST_MEMORY and DEVICE_MEMORY are always
+ if (device_type != DEVICE_GPU && device_type != DEVICE_SYCL ) {
+ // On non-GPU and non-SYCL devices, HOST_MEMORY and DEVICE_MEMORY are always
// compatible.
return Status::OK();
}
// For GPU device, HOST_MEMORY and DEVICE_MEMORY is not
// compatible. I.e., a conversion/transfer must be done.
//
// {node id, slot id} -> memory type.
@@ -47,12 +47,12 @@ struct EndpointEq {
return Status::OK();
}
- // For GPU device, HOST_MEMORY and DEVICE_MEMORY is not
+ // For GPU and SYCL device, HOST_MEMORY and DEVICE_MEMORY is not
// compatible. I.e., a conversion/transfer must be done.
//